from typing import List

import win32print


def get_all_printers() -> List[str]:
    """
    :return: list of the printers names
    """
    return [i[2] for i in win32print.EnumPrinters(2)]


def get_default_printer() -> str:
    """
    :return: the default printer's name
    """
    return win32print.GetDefaultPrinter()



from setuptools import setup, find_packages

setup(
    name='pyrinter',
    version='0.0.1a1',
    packages=find_packages(include=['pyrinter', 'pyrinter.*']),
    author='Hod Vaknin',
    license='MIT',

    description='python printer package',
    long_description=open('README.md').read(),
    long_description_content_type='text/markdown',
    project_urls={
        'Source': 'https://github.com/hodvak/py-printer'
    },

    install_requires=['pywin32'],

    classifiers=[
        'License :: OSI Approved :: MIT License',
        'Environment :: Win32 (MS Windows)',
        'Operating System :: Microsoft :: Windows',
        'Programming Language :: Python :: 3'
    ]

)


